@@ -7,18 +7,30 @@ bestLinear <- function(y, experts, lambda = 0, loss.type = list(name = "square")
   
   coefficients <- NULL
   if (loss.type$name == "square") {
-    coefficients <- solve(lambda * diag(1, ncol(experts)) + t(experts) %*% experts, 
-      t(experts) %*% y)
-    
+    coefficients <- 
+      tryCatch(
+        solve(lambda * diag(1, ncol(experts)) + t(experts) %*% experts, t(experts) %*% y),
+        error = function(err){
+          lambda = 1e-14
+          solve(lambda * diag(1, ncol(experts)) + t(experts) %*% experts, t(experts) %*% y)
+          warning("Ill conditioned problem. Regularized with lambda = 1e-14.")
+        })
+      
   } else if (loss.type$name == "pinball") {
     if (is.null(loss.type$tau)) {
       loss.type$tau <- 0.5
     }
-    coefficients <- tryCatch({
-      quantreg::rq(y ~ experts - 1, tau = loss.type$tau)$coefficients
-    }, error = function(e) {
-      NULL
-    })
+    if (!requireNamespace("quantreg", quietly = TRUE)) {
+        warning("The quantreg package must be installed to use this functionality")
+        #Either exit or do something without quantreg
+        return(NULL)
+      } else {
+        coefficients <- tryCatch({
+          quantreg::rq(y ~ experts - 1, tau = loss.type$tau)$coefficients
+        }, error = function(e) {
+          NULL
+        })
+      }
   }
   if (is.null(coefficients)) {
     warning("The best linear oracle is only approximated (using optim).")
